aboutsummaryrefslogtreecommitdiff
path: root/mod/mod-ci-github.cxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2024-05-08 12:21:10 +0200
committerFrancois Kritzinger <francois@codesynthesis.com>2024-05-13 09:17:32 +0200
commit07cddc413adaeec821eeac476b9c222f32f6bcde (patch)
tree6ae32582552bf1e52a8e2c20366db9025191111e /mod/mod-ci-github.cxx
parent4b12e94d00f2891c188b5e598cd63fee1ca46cf2 (diff)
Review
Diffstat (limited to 'mod/mod-ci-github.cxx')
-rw-r--r--mod/mod-ci-github.cxx13
1 files changed, 7 insertions, 6 deletions
diff --git a/mod/mod-ci-github.cxx b/mod/mod-ci-github.cxx
index fc3fca3..d3c8407 100644
--- a/mod/mod-ci-github.cxx
+++ b/mod/mod-ci-github.cxx
@@ -872,7 +872,7 @@ namespace brep
to_string (rs));
}
- assert (false);
+ return ""; // Should never reach.
};
// Prepare the check run's summary field (the build information in an
@@ -885,10 +885,11 @@ namespace brep
ostringstream os;
xml::serializer s (os, "check_run_summary");
// @@ TMP Hack required to disable XML element name prefixes (which
// GitHub does not like). The XHTML elsewhere in brep always
// starts with an <html> element which sets up the
// namespace/prefix just like this.
//
struct table: element
{
@@ -977,7 +978,7 @@ namespace brep
//
gq_built_result br (gh_to_conclusion (*b.status, sd.warning_success),
circle (*b.status) + ' ' +
- ucase (to_string (*b.status)),
+ ucase (to_string (*b.status)),
move (sm));
if (cr.node_id)
@@ -885,10 +885,11 @@ namespace brep
ostringstream os;
xml::serializer s (os, "check_run_summary");
- // @@ TMP Hack required to disable XML element name prefixes (which
- // GitHub does not like). The XHTML elsewhere in brep always
- // starts with an <html> element which sets up the
- // namespace/prefix just like this.
+ // This hack is required to disable XML element name prefixes (which
+ // GitHub does not like). Note that this adsd an xmlns declaration for
+ // the XHTML namespace which for now GitHub appears to ignore. If that
+ // ever becomes a problem, then we should redo this with raw XML
+ // serializer calls.
//
struct table: element